import { Component, InjectionToken, ɵɵdefineInjectable, ɵɵinject, Injectable, Inject, EventEmitter, Directive, Input, Output, HostListener, NgModule } from '@angular/core';
import { NgbActiveModal, NgbModal } from '@ng-bootstrap/ng-bootstrap';
import { __awaiter } from 'tslib';

class ConfirmComponent {
    constructor(modal) {
        this.modal = modal;
    }
}
ConfirmComponent.decorators = [
    { type: Component, args: [{
                selector: 'usl-confirm',
                template: "<div class=\"modal-body pw\" [innerHTML]=\"message\"></div>\n\n<div class=\"modal-footer\">\n  <button class=\"btn btn-outline-dark\" type=\"button\" (click)=\"modal.dismiss()\">{{ cancel }}</button>\n  <button class=\"btn btn-primary\" type=\"button\" (click)=\"modal.close()\" ngbAutofocus>{{ ok }}</button>\n</div>\n",
                styles: [".pw{word-break:break-word;white-space:pre-wrap}"]
            },] }
];
ConfirmComponent.ctorParameters = () => [
    { type: NgbActiveModal }
];

const config = new InjectionToken('bootstrap-confirm');

class ConfirmService {
    constructor(config, modalService) {
        this.config = config;
        this.modalService = modalService;
    }
    setDefaults(title, ok, cancel) {
        var _a;
        (_a = this.config) !== null && _a !== void 0 ? _a : (this.config = {});
        this.config.ok = ok;
        this.config.cancel = cancel;
    }
    confirm(msg, ok, cancel) {
        var _a, _b;
        if (ok === void 0) { ok = ((_a = this.config) === null || _a === void 0 ? void 0 : _a.ok) || 'Ok'; }
        if (cancel === void 0) { cancel = ((_b = this.config) === null || _b === void 0 ? void 0 : _b.cancel) || 'Cancel'; }
        return new Promise(resolve => {
            const modalRef = this.modalService.open(ConfirmComponent, { ariaLabelledBy: 'modal-basic-title' });
            modalRef.result.then(() => resolve(true), () => resolve(false));
            modalRef.componentInstance.ok = ok;
            modalRef.componentInstance.cancel = cancel;
            modalRef.componentInstance.message = msg;
        });
    }
}
ConfirmService.ɵprov = ɵɵdefineInjectable({ factory: function ConfirmService_Factory() { return new ConfirmService(ɵɵinject(config), ɵɵinject(NgbModal)); }, token: ConfirmService, providedIn: "root" });
ConfirmService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
ConfirmService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [config,] }] },
    { type: NgbModal }
];

class ConfirmDirective {
    constructor(confirmService) {
        this.confirmService = confirmService;
        this.confirm = new EventEmitter();
    }
    onClick() {
        return __awaiter(this, void 0, void 0, function* () {
            const promise = this.confirmService.confirm(this.confirmMessage, this.confirmOk, this.confirmCancel);
            if (yield promise) {
                this.confirm.emit();
            }
        });
    }
}
ConfirmDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line:directive-selector
                selector: '[confirm]'
            },] }
];
ConfirmDirective.ctorParameters = () => [
    { type: ConfirmService }
];
ConfirmDirective.propDecorators = {
    confirmMessage: [{ type: Input }],
    confirmOk: [{ type: Input }],
    confirmCancel: [{ type: Input }],
    confirm: [{ type: Output }],
    onClick: [{ type: HostListener, args: ['click',] }]
};

class BootstrapConfirmModule {
    static config(conf) {
        return {
            ngModule: BootstrapConfirmModule,
            providers: [
                {
                    provide: config,
                    useValue: conf
                }
            ]
        };
    }
}
BootstrapConfirmModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ConfirmDirective,
                    ConfirmComponent
                ],
                imports: [],
                exports: [
                    ConfirmDirective
                ],
                providers: [
                    ConfirmService
                ]
            },] }
];

/*
 * Public API Surface of bootstrap-confirm
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BootstrapConfirmModule, ConfirmComponent, ConfirmDirective, ConfirmService, config };
//# sourceMappingURL=kovalenko-bootstrap-confirm.js.map
